@@ -44,7 +44,7 @@ from ironicclient import exc
 #             http://specs.openstack.org/openstack/ironic-specs/specs/kilo/api-microversions.html # noqa
 #             for full details.
 DEFAULT_VER = '1.9'
-LAST_KNOWN_API_VERSION = 56
+LAST_KNOWN_API_VERSION = 58
 LATEST_VERSION = '1.{}'.format(LAST_KNOWN_API_VERSION)
 
 LOG = logging.getLogger(__name__)
@@ -118,11 +118,7 @@ class VersionNegotiationMixin(object):
                                 str(self.os_ironic_api_version).split('.')[0])
             else:
                 base_version = API_VERSION
-            # Raise exception on client or server error.
-            resp = self._make_simple_request(conn, 'GET', base_version)
-            if not resp.ok:
-                raise exc.from_response(resp, method='GET', url=base_version)
-            return resp
+            return self._make_simple_request(conn, 'GET', base_version)
 
         version_overridden = False
 
