@@ -14,6 +14,8 @@
 #   under the License.
 #
 
+import json
+
 import mock
 from osc_lib.tests import utils
 
@@ -64,6 +66,7 @@ BAREMETAL_PORT = {
 baremetal_driver_hosts = ['fake-host1', 'fake-host2']
 baremetal_driver_name = 'fakedrivername'
 baremetal_driver_type = 'classic'
+baremetal_driver_default_bios_if = 'bios'
 baremetal_driver_default_boot_if = 'boot'
 baremetal_driver_default_console_if = 'console'
 baremetal_driver_default_deploy_if = 'deploy'
@@ -72,8 +75,10 @@ baremetal_driver_default_management_if = 'management'
 baremetal_driver_default_network_if = 'network'
 baremetal_driver_default_power_if = 'power'
 baremetal_driver_default_raid_if = 'raid'
+baremetal_driver_default_rescue_if = 'rescue'
 baremetal_driver_default_storage_if = 'storage'
 baremetal_driver_default_vendor_if = 'vendor'
+baremetal_driver_enabled_bios_ifs = ['bios', 'bios2']
 baremetal_driver_enabled_boot_ifs = ['boot', 'boot2']
 baremetal_driver_enabled_console_ifs = ['console', 'console2']
 baremetal_driver_enabled_deploy_ifs = ['deploy', 'deploy2']
@@ -82,6 +87,7 @@ baremetal_driver_enabled_management_ifs = ['management', 'management2']
 baremetal_driver_enabled_network_ifs = ['network', 'network2']
 baremetal_driver_enabled_power_ifs = ['power', 'power2']
 baremetal_driver_enabled_raid_ifs = ['raid', 'raid2']
+baremetal_driver_enabled_rescue_ifs = ['rescue', 'rescue2']
 baremetal_driver_enabled_storage_ifs = ['storage', 'storage2']
 baremetal_driver_enabled_vendor_ifs = ['vendor', 'vendor2']
 
@@ -89,6 +95,7 @@ BAREMETAL_DRIVER = {
     'hosts': baremetal_driver_hosts,
     'name': baremetal_driver_name,
     'type': baremetal_driver_type,
+    'default_bios_interface': baremetal_driver_default_bios_if,
     'default_boot_interface': baremetal_driver_default_boot_if,
     'default_console_interface': baremetal_driver_default_console_if,
     'default_deploy_interface': baremetal_driver_default_deploy_if,
@@ -97,8 +104,10 @@ BAREMETAL_DRIVER = {
     'default_network_interface': baremetal_driver_default_network_if,
     'default_power_interface': baremetal_driver_default_power_if,
     'default_raid_interface': baremetal_driver_default_raid_if,
+    'default_rescue_interface': baremetal_driver_default_rescue_if,
     'default_storage_interface': baremetal_driver_default_storage_if,
     'default_vendor_interface': baremetal_driver_default_vendor_if,
+    'enabled_bios_interfaces': baremetal_driver_enabled_bios_ifs,
     'enabled_boot_interfaces': baremetal_driver_enabled_boot_ifs,
     'enabled_console_interfaces': baremetal_driver_enabled_console_ifs,
     'enabled_deploy_interfaces': baremetal_driver_enabled_deploy_ifs,
@@ -107,6 +116,7 @@ BAREMETAL_DRIVER = {
     'enabled_network_interfaces': baremetal_driver_enabled_network_ifs,
     'enabled_power_interfaces': baremetal_driver_enabled_power_ifs,
     'enabled_raid_interfaces': baremetal_driver_enabled_raid_ifs,
+    'enabled_rescue_interfaces': baremetal_driver_enabled_rescue_ifs,
     'enabled_storage_interfaces': baremetal_driver_enabled_storage_ifs,
     'enabled_vendor_interfaces': baremetal_driver_enabled_vendor_ifs,
 }
@@ -138,6 +148,8 @@ PORTGROUP = {'uuid': baremetal_portgroup_uuid,
 
 VIFS = {'vifs': [{'id': 'aaa-aa'}]}
 TRAITS = ['CUSTOM_FOO', 'CUSTOM_BAR']
+BIOS_SETTINGS = [{'name': 'bios_name_1', 'value': 'bios_value_1', 'links': []},
+                 {'name': 'bios_name_2', 'value': 'bios_value_2', 'links': []}]
 
 baremetal_volume_connector_uuid = 'vvv-cccccc-vvvv'
 baremetal_volume_connector_type = 'iqn'
@@ -170,6 +182,43 @@ VOLUME_TARGET = {
     'properties': baremetal_volume_target_properties,
 }
 
+baremetal_hostname = 'compute1.localdomain'
+baremetal_conductor_group = 'foo'
+baremetal_alive = True
+baremetal_drivers = ['fake-hardware']
+CONDUCTOR = {
+    'hostname': baremetal_hostname,
+    'conductor_group': baremetal_conductor_group,
+    'alive': baremetal_alive,
+    'drivers': baremetal_drivers,
+}
+
+baremetal_allocation_state = 'active'
+baremetal_resource_class = 'baremetal'
+ALLOCATION = {
+    'resource_class': baremetal_resource_class,
+    'uuid': baremetal_uuid,
+    'name': baremetal_name,
+    'state': baremetal_allocation_state,
+    'node_uuid': baremetal_uuid,
+}
+
+baremetal_deploy_template_uuid = 'ddd-tttttt-dddd'
+baremetal_deploy_template_name = 'DeployTemplate-name'
+baremetal_deploy_template_steps = json.dumps([{
+    'interface': 'raid',
+    'step': 'create_configuration',
+    'args': {},
+    'priority': 10
+}])
+baremetal_deploy_template_extra = {'key1': 'value1', 'key2': 'value2'}
+DEPLOY_TEMPLATE = {
+    'uuid': baremetal_deploy_template_uuid,
+    'name': baremetal_deploy_template_name,
+    'steps': baremetal_deploy_template_steps,
+    'extra': baremetal_deploy_template_extra,
+}
+
 
 class TestBaremetal(utils.TestCommand):
 
